@@ -96,7 +96,7 @@ def augment_and_training_report(models_list, GCS_DS_PATH, train_tfrec_path, val_
 
 
 
-def augment_and_train(model, GCS_DS_PATH, train_tfrec_path, val_tfrec_path, batch_size, callbacks = None, plot = False):
+def augment_and_train(model, GCS_DS_PATH, train_tfrec_path, val_tfrec_path, batch_size, epochs, steps_per_epoch, callbacks = None, plot = False):
 
 	from quick_ml.begin_tpu import get_training_dataset
 	from quick_ml.begin_tpu import get_validation_dataset
